@@ -1,6 +1,7 @@
-import os
+"""LightningFlower Utility"""
 import inspect
 import numpy as np
+import os
 import secrets
 from pathlib import Path
 
@@ -30,10 +31,12 @@ def load_params(full_filepath):
 
 
 def boolean_string(s):
+    """String to bool conversion"""
     if s not in {'False', 'True'}:
         raise ValueError('Not a valid boolean string')
     return s == 'True'
 
 
 def create_dir(path):
+    """Creating a directory, check if directory exists"""
     return Path(path).mkdir(parents=True, exist_ok=True)
